GAE pytz
========

A fork of pytz which works on [Google App Engine][1].

Based on [http://appengine-cookbook.appspot.com/recipe/caching-pytz-helper/][2] but modified so that it can be imported normally with `import pytz`.


[1]: https://developers.google.com/appengine/
[2]: http://appengine-cookbook.appspot.com/recipe/caching-pytz-helper/
